summaryrefslogtreecommitdiffstatshomepage
path: root/3rdparty/ymfm/src/ymfm_opm.h
diff options
context:
space:
mode:
Diffstat (limited to '3rdparty/ymfm/src/ymfm_opm.h')
-rw-r--r--3rdparty/ymfm/src/ymfm_opm.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/3rdparty/ymfm/src/ymfm_opm.h b/3rdparty/ymfm/src/ymfm_opm.h
index d35a0168e7c..ad657ac0159 100644
--- a/3rdparty/ymfm/src/ymfm_opm.h
+++ b/3rdparty/ymfm/src/ymfm_opm.h
@@ -49,7 +49,8 @@ namespace ymfm
// OPM register map:
//
// System-wide registers:
// 01 xxxxxxxx Test register
// 08 -x------ Key on/off operator 4
// --x----- Key on/off operator 3
// ---x---- Key on/off operator 2
@@ -172,6 +173,7 @@ public:
// system-wide registers
uint32_t test() const { return byte(0x01, 0, 8); }
+ uint32_t lfo_reset() const { return byte(0x01, 1, 1); }
uint32_t noise_frequency() const { return byte(0x0f, 0, 5); }
uint32_t noise_enable() const { return byte(0x0f, 7, 1); }
uint32_t timer_a_value() const { return word(0x10, 0, 8, 0x11, 0, 2); }
@@ -49,7 +49,8 @@ namespace ymfm
//
// System-wide registers:
-// 01 xxxxxxxx Test register
+// 01 xxxxxx-x Test register
+// ------x- LFO reset
// 08 -x------ Key on/off operator 4
// --x----- Key on/off operator 3